package com.jsowell.pile.mapper;

import com.jsowell.pile.domain.DockingPlatformConfig;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 对接平台配置信息Mapper接口
 *
 * @author jsowell
 * @date 2023-05-27
 */
@Repository
public interface DockingPlatformConfigMapper {
    /**
     * 查询对接平台配置信息
     *
     * @param id 对接平台配置信息主键
     * @return 对接平台配置信息
     */
    public DockingPlatformConfig selectDockingPlatformConfigById(Integer id);

    /**
     * 查询对接平台配置信息列表
     *
     * @param dockingPlatformConfig 对接平台配置信息
     * @return 对接平台配置信息集合
     */
    public List<DockingPlatformConfig> selectDockingPlatformConfigList(DockingPlatformConfig dockingPlatformConfig);

    /**
     * 新增对接平台配置信息
     *
     * @param dockingPlatformConfig 对接平台配置信息
     * @return 结果
     */
    public int insertDockingPlatformConfig(DockingPlatformConfig dockingPlatformConfig);

    /**
     * 修改对接平台配置信息
     *
     * @param dockingPlatformConfig 对接平台配置信息
     * @return 结果
     */
    public int updateDockingPlatformConfig(DockingPlatformConfig dockingPlatformConfig);

    /**
     * 删除对接平台配置信息
     *
     * @param id 对接平台配置信息主键
     * @return 结果
     */
    public int deleteDockingPlatformConfigById(Integer id);

    /**
     * 批量删除对接平台配置信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDockingPlatformConfigByIds(Integer[] ids);

    /**
     * 通过operatorId查询配置信息
     *
     * @param operatorId
     * @return
     */
    DockingPlatformConfig getInfoByOperatorId(String operatorId);
}
